@@ -16,6 +16,8 @@ class FRAMEWORK:
     OPENVINO = "openvino"
     TORCH = "torch"
     TORCH_GPU = "torch_gpu"
+    KERAS = "keras"
+    CAFFE = "caffe"
 
 
 # =====================================================================================================================
@@ -45,6 +47,12 @@ class DEVICE:
         CPU = "CPU"
         CUDA = "CUDA"
 
+    class CAFFE:
+        CPU = "CPU"
+
+    class KERAS:
+        CPU = "CPU"
+
 
 # =====================================================================================================================
 SUPPORT_DEVICES = {
@@ -55,7 +63,9 @@ SUPPORT_DEVICES = {
         FRAMEWORK.OPENVINO: [DEVICE.OPENVINO.CPU, DEVICE.OPENVINO.MYRIAD, DEVICE.OPENVINO.GPU, DEVICE.OPENVINO.GNA],
         # OV_FPGA, OV_HDDL
         FRAMEWORK.TORCH: [DEVICE.TORCH.CPU],
-        FRAMEWORK.TORCH_GPU: [DEVICE.TORCH.CPU, DEVICE.TORCH.CUDA]
+        FRAMEWORK.TORCH_GPU: [DEVICE.TORCH.CPU, DEVICE.TORCH.CUDA],
+        FRAMEWORK.CAFFE: [DEVICE.CAFFE.CPU],
+        FRAMEWORK.KERAS: [DEVICE.KERAS.CPU]
     },
     ARCHITECTURE.AARCH64: {},
     ARCHITECTURE.ARMV7HF: {}
@@ -72,6 +82,8 @@ class MODEL_TYPE:
     OPENVINO = "OPENVINO"
     TF_LITE = "TF_LITE"
     TORCH = "TORCH"
+    KERAS = "KERAS"
+    CAFFE = "CAFFE"
 
 
 # =====================================================================================================================
